@@ -39,23 +39,152 @@ class Config:
         self._config_path = path if path is not None else self._get_config_path()
 
     def _get_config_path(self):
-        """Get the path to the config file, preferring user config over package default."""
-        # Determine user config directory
-        if os.name == 'nt':  # Windows
-            user_config_dir = Path(os.environ.get('APPDATA', '')) / 'pivtools'
-        else:  # Unix-like (macOS, Linux)
-            user_config_dir = Path.home() / '.config' / 'pivtools'
+        """Get the path to the config file in the current working directory."""
+        # Always use current working directory (like CLI)
+        cwd_config_path = Path.cwd() / 'config.yaml'
         
-        user_config_dir.mkdir(parents=True, exist_ok=True)
-        user_config_path = user_config_dir / 'config.yaml'
-        
-        # If user config doesn't exist, copy from package default
-        if not user_config_path.exists():
+        # If config doesn't exist, copy from package default or create programmatically
+        if not cwd_config_path.exists():
             package_default = Path(__file__).parent / 'config.yaml'
             if package_default.exists():
-                shutil.copy2(package_default, user_config_path)
+                shutil.copy2(package_default, cwd_config_path)
+            else:
+                # Fallback: create default config programmatically (like CLI)
+                default_config = """
+paths:
+  base_paths:
+  - ./copy_here
+  source_paths:
+  - ./copy_here
+  camera_numbers:
+  - 1
+  camera_count: 1
+images:
+  num_images: 100
+  image_format: 
+    - B%05d_A.tif
+    - B%05d_B.tif
+  vector_format:
+    - B%05d.mat
+  time_resolved: false
+  dtype: float32
+batches:
+  size: 25
+logging:
+  file: pypiv.log
+  level: INFO
+  console: true
+processing:
+  instantaneous: true
+  ensemble: false
+  stereo: false
+  backend: cpu
+  debug: false
+  auto_compute_params: false
+  omp_threads: 4
+  dask_workers_per_node: 5
+  dask_threads_per_worker: 1
+  dask_memory_limit: 12GB
+outlier_detection:
+  enabled: true
+  methods:
+  - threshold: 0.25
+    type: peak_mag
+  - epsilon: 0.2
+    threshold: 2
+    type: median_2d
+infilling:
+  mid_pass:
+    method: biharmonic
+    parameters:
+      ksize: 3
+  final_pass:
+    enabled: true
+    method: biharmonic
+    parameters:
+      ksize: 3
+plots:
+  save_extension: .png
+  save_pickle: true
+  fontsize: 14
+  title_fontsize: 16
+videos:
+- endpoint: ''
+  type: instantaneous
+  use_merged: false
+  variable: ux
+  video_length: 100
+statistics_extraction: null
+instantaneous_piv:
+  window_size:
+  - - 128
+    - 128
+  - - 64
+    - 64
+  - - 32
+    - 32
+  overlap:
+  - 50
+  - 50
+  - 50
+  runs:
+  - 3
+  time_resolved: false
+  window_type: gaussian
+  num_peaks: 1
+  peak_finder: gauss3
+  secondary_peak: false
+calibration_format:
+  image_format: calib%05d.tif
+calibration:
+  active: pinhole
+  scale_factor:
+    dt: 0.56
+    px_per_mm: 3.41
+    source_path_idx: 0
+  pinhole:
+    source_path_idx: 0
+    camera: 1
+    image_index: 0
+    file_pattern: calib%05d.tif
+    pattern_cols: 10
+    pattern_rows: 10
+    dot_spacing_mm: 28.89
+    enhance_dots: true
+    asymmetric: false
+    dot_distance_mm: 28.9
+    grid_tolerance: 0.5
+    ransac_threshold: 3
+    dt: 0.0275
+  stereo:
+    source_path_idx: 0
+    camera_pair:
+    - 1
+    - 2
+    file_pattern: planar_calibration_plate_*.tif
+    pattern_cols: 10
+    pattern_rows: 10
+    dot_spacing_mm: 28.89
+    enhance_dots: true
+    asymmetric: false
+    dt: 2
+filters:
+- type: pod
+masking:
+  enabled: true
+  mask_file_pattern: mask_Cam%d.mat
+  mask_threshold: 0.01
+  mode: file
+  rectangular:
+    top: 64
+    bottom: 64
+    left: 0
+    right: 0
+"""
+                with open(cwd_config_path, 'w') as f:
+                    f.write(default_config.strip())
         
-        return user_config_path
+        return cwd_config_path
 
     @property
     def config_path(self):
@@ -74,12 +203,25 @@ class Config:
     @property
     def image_format(self):
         if self.time_resolved:
-            return self.data["images"].get("image_format", "B%05d.tiff")
+            fmt = self.data["images"].get("image_format", "B%05d.tiff")
+            logging.info(f"time_resolved image_format: {fmt}, type: {type(fmt)}")
+            return fmt
         else:
             # Expect a list of two formats in the config for A and B images
             fmts = self.data["images"].get(
                 "image_format", ["B%05d_A.tiff", "B%05d_B.tiff"]
             )
+            if isinstance(fmts, str):
+                raise ValueError(
+                    "image_format must be a list of two strings when time_resolved is false. "
+                    f"Got string: {fmts}"
+                )
+            if not isinstance(fmts, (list, tuple)) or len(fmts) != 2:
+                raise ValueError(
+                    "image_format must be a list or tuple of exactly two strings when time_resolved is false. "
+                    f"Got: {fmts}, type: {type(fmts)}"
+                )
+            logging.info(f"non-time_resolved fmts: {fmts}, type: {type(fmts)}")
             return tuple(fmts)
 
     @property
@@ -146,49 +288,53 @@ class Config:
         camera_num = self.camera_numbers[0]
         image_format = self.image_format
         
-        try:
-            # Handle different image format cases
-            if '.set' in str(image_format):
-                # For .set files, they're in the source directory
-                if isinstance(image_format, tuple):
-                    file_path = source_path / image_format[0]
-                else:
-                    file_path = source_path / image_format
-                img = read_image(str(file_path), camera_no=camera_num, im_no=1)
-            elif '.im7' in str(image_format):
-                # For .im7 files, they're in the source directory (all cameras in one file)
-                if isinstance(image_format, tuple):
-                    file_path = source_path / (image_format[0] % 1)
-                else:
-                    file_path = source_path / (image_format % 1)
-                img = read_image(str(file_path), camera_no=camera_num)
+        logging.info(f"_detect_image_shape: image_format = {image_format}, type = {type(image_format)}")
+        logging.info(f"Source path: {source_path}, Camera: {camera_num}")
+        
+        # Use same logic as GUI for determining source path
+        if isinstance(image_format, tuple):
+            format_str = image_format[0]
+        else:
+            format_str = image_format
+        
+        if '.set' in str(format_str) or '.im7' in str(format_str):
+            # For .set/.im7 files: all cameras in source directory
+            if isinstance(image_format, tuple):
+                file_path = source_path / (image_format[0] % 1)
             else:
-                # Regular files in camera subdirectories
-                camera_path = source_path / f"Cam{camera_num}"
-                
-                if isinstance(image_format, tuple):
-                    # Non-time-resolved: use first format (A frame)
-                    file_path = camera_path / (image_format[0] % 1)
-                else:
-                    # Time-resolved: single format
-                    file_path = camera_path / (image_format % 1)
-                
-                img = read_image(str(file_path))
+                file_path = source_path / (image_format % 1)
+            logging.info(f"Trying to read .set/.im7 file: {file_path}")
+        else:
+            # For regular files: in camera subdirectories
+            camera_path = source_path / f"Cam{camera_num}"
+            if isinstance(image_format, tuple):
+                file_path = camera_path / (image_format[0] % 1)
+            else:
+                file_path = camera_path / (image_format % 1)
+            logging.info(f"Trying to read regular file: {file_path}")
+        
+        if not file_path.exists():
+            raise FileNotFoundError(f"Image file not found: {file_path}. Check your source_path and image_format in config.yaml")
+        
+        try:
+            img = read_image(str(file_path))
             
             # Handle both single images and image pairs
             if img.ndim == 3 and img.shape[0] == 2:
                 # Image pair returned (e.g., from .im7)
-                return tuple(img.shape[1:])
+                shape = tuple(img.shape[1:])
             else:
                 # Single image
-                return tuple(img.shape)
-                
+                shape = tuple(img.shape)
+            
+            logging.info(f"Detected image shape: {shape}")
+            return shape
+            
         except Exception as e:
-            logging.error("Failed to auto-detect image shape: %s", e)
-            logging.error("Please specify 'shape' in config.yaml under 'images' section")
+            logging.error("Failed to read image: %s", e)
             raise ValueError(
-                f"Could not auto-detect image shape. Please add 'shape: [H, W]' "
-                f"to the 'images' section of your config.yaml. Error: {e}"
+                f"Could not read image file {file_path}. Error: {e}. "
+                "Check that the file exists and is a valid image format."
             )
 
     @property
