@@ -8,8 +8,8 @@ from flask import Blueprint, jsonify, request, send_file
 from loguru import logger
 from scipy.io import loadmat
 
-from ....config import get_config
-from ....paths import get_data_paths
+from pivtools_core.config import get_config
+from pivtools_core.paths import get_data_paths
 from ..pod_decompose import pod_decompose
 
 POD_bp = Blueprint("POD", __name__)
